interface ICronTaskRunInfo {
    running: boolean;
    lastRunningTm: number;
}
export default abstract class CkCronTask {
    private IS_DEBUG_LEVEL_LOG;
    protected TASK_STATE: ICronTaskRunInfo;
    /**
     * cron task 초기화. 상속 받는 곳에서 주로 overwrite 해서 사용 한다.
     * cron 동작시 init(), run() 이 세트로 실행 된다.
     * 즉, task 실행시 마다 init 는 실행 된다. 만일 최초 한번 초기화를 해야 한다면 constructor 에서 처리 하도록 한다.
     *
     * @param isHideDefaultLog {boolean | undefined} 라이브러리의 기본 로그를 숨길지 여부. true 라면 기본 로그를 debug 레벨로 찍는다. task 실행시 매 번 로그가 info 레벨로 찍히는 것을 막기 위해서 추가 함.
     * @returns {void} 리턴값 없음
     */
    init(isHideDefaultLog?: boolean): void;
    /**
     * cron task 가 동작 중인지 확인
     *
     * @returns {void} 리턴값 없음
     */
    isRunning(): boolean;
    /**
     * cron task 동작 시작
     *
     * @param lhd {string} 로그키
     * @returns {void} 리턴값 없음
     */
    setRunning(lhd: string): void;
    /**
     * cron task 종료.
     * cron task 가 종료 된다면 반듯이 호출 되어야 한다.
     *
     * @param lhd {string} 로그키
     * @returns {void} 리턴값 없음
     */
    taskEnd(lhd: string): void;
    /**
     * 상속 받는 곳에서 구현 해야 한다.
     * cron task 동작
     * @param lhd {string} 로그키
     */
    abstract run(lhd: string): void;
}
export {};
